/* $Id: simplemod.c,v 1.5 2011/06/20 17:39:57 xi Exp $ */

/******************************************************************************
*    simplemod - A very simple module player
*    Copyright (C) 2002  Christian Laursen <xi@borderworlds.dk>
*
*    This program is free software; you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation; either version 2 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program; if not, write to the Free Software
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#include <mikmod.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#define VERSION "1.1"

int main (int argc, char **argv)
{
  int i;
  char *filename = (char *)0;
  int skip = 0, esd = 0, raw = 0;
  char *esdhost;
  MODULE *module;

  for (i = 1; i < argc; ++i) {
    if (!strcmp(argv[i], "-k") && (i + 1 < argc)) {
      skip = atoi(argv[++i]);
    } else if (!strcmp(argv[i], "-e") && (i + 1 < argc)) {
      esd = 1;
      esdhost = argv[++i];
    } else if (!strcmp(argv[i], "-r")) {
      raw = 1;
    } else {
      if (filename) {
	fprintf(stderr, "You can only play one song at a time.\n");
	exit(1);
      } else {
	filename = argv[i];
      }
    }
  }

  if (!filename) {
    fprintf(stderr, "No filename specified.\n");
    exit(1);
  }

  fprintf(stderr, "simplemod %s\nCopyright 2002-2011   Christian Laursen <xi@borderworlds.dk>\n\n", VERSION);

  if (esd) {
    setenv("ESPEAKER", esdhost, 1);
    MikMod_RegisterDriver(&drv_esd);
  } else if (raw) {
    MikMod_RegisterDriver(&drv_stdout);
  } else {
    MikMod_RegisterDriver(&drv_oss);
  }
  MikMod_RegisterAllLoaders();

  md_mode |= DMODE_SOFT_MUSIC;
  md_reverb = 0;
  if (MikMod_Init("")) {
    fprintf(stderr, "Could not initialize sound, reason: %s\n", MikMod_strerror(MikMod_errno));
    exit(1);
  }

  module = Player_Load(filename, 64, 0);

  if (module) {
    fprintf(stderr, "Title: %s\n\n", module->songname);

    module->loop = 0;
    /* start module */
    Player_Start(module);
    Player_SetPosition(skip);
     
    while (Player_Active()) {
      /* we're playing */
      usleep(1000);
      MikMod_Update();
      
      fprintf (stderr, "P:%5d,%d             \r", (int)(module->sngtime / (1<<10)), module->sngpos);
      fflush(stderr);
    }

    Player_Stop();
    Player_Free(module);
  } else {
    fprintf(stderr, "Could not load module, reason: %s\n", MikMod_strerror(MikMod_errno));
    exit(1);    
  }

  MikMod_Exit();

  return 0;
}
